@@ -1,9 +1,9 @@
 package Net::Google::DataAPI::Role::Entry;
-use Any::Moose '::Role';
+use Moose::Role;
+use namespace::clean -except => 'meta';
 use Carp;
 use XML::Atom;
 use XML::Atom::Entry;
-our $VERSION = '0.02';
 
 has container => (
     isa => 'Maybe[Net::Google::DataAPI::Role::Entry]',
@@ -26,22 +26,8 @@ my %rel2label = (
     self => 'selfurl',
 );
 
-for my $label (values %rel2label) {
-    has $label => (
-        isa => 'Str',
-        is => 'ro',
-        lazy_build => 1,
-    );
-
-    __PACKAGE__->meta->add_method(
-        "_build_$label" => sub {
-            my $self = shift;
-            for my $link ($self->atom->link) {
-                my $rel = $rel2label{$link->rel} or next;
-                return $link->href if $rel eq $label;
-            }
-        }
-    );
+for (values %rel2label) {
+    has $_ => (isa => 'Str', is => 'ro');
 }
 
 has atom => (
@@ -59,49 +45,35 @@ has atom => (
 has id => (
     isa => 'Str',
     is => 'ro',
-    lazy_build => 1,
 );
 
-sub _build_id {
-    my $self = shift;
-    $self->atom->get($self->atom->ns, 'id') || '';
-}
-
 has title => (
     isa => 'Str',
     is => 'rw',
-    trigger => sub {$_[0]->update},
-    lazy_build => 1,
+    default => 'untitled',
+    trigger => sub {$_[0]->update}
 );
 
-sub _build_title {
-    my $self = shift;
-    $self->atom ? $self->atom->title : 'untitled';
-}
-
 has etag => (
     isa => 'Str',
     is => 'rw',
-    lazy_build => 1,
 );
 
-sub _build_etag {
-    my $self = shift;
-    $self->atom or return '';
-    $self->elem->getAttributeNS($self->ns('gd')->{uri}, 'etag');
-}
-
 
 sub from_atom {
     my ($self) = @_;
-    for my $attr ($self->meta->get_all_attributes) {
-        $attr->name eq 'service' and next;
-        $attr->clear_value($self) if $attr->{lazy};
+    $self->{title} = $self->atom->title;
+    $self->{id} = $self->atom->get($self->atom->ns, 'id');
+    $self->etag($self->elem->getAttributeNS($self->ns('gd')->{uri}, 'etag'));
+    for ($self->atom->link) {
+        my $label = $rel2label{$_->rel} or next;
+        $self->{$label} = $_->href;
     }
 }
 
 sub to_atom {
     my ($self) = @_;
+    $XML::Atom::DefaultVersion = 1;
     my $entry = XML::Atom::Entry->new;
     $entry->title($self->title);
     return $entry;
@@ -133,8 +105,6 @@ sub delete {
     return $res->is_success;
 }
 
-no Any::Moose '::Role';
-
 1;
 
 __END__
@@ -148,7 +118,7 @@ Net::Google::DataAPI::Role::Entry - represents entry of Google Data API
 =head1 SYNOPSIS
 
     package MyEntry;
-    use Any::Moose;
+    use Moose;
     use Net::Google::DataAPI;
     with 'Net::Google::DataAPI::Role::Entry';
 
@@ -167,7 +137,7 @@ Net::Google::DataAPI::Role::Entry provides base functionalities for the entry of
 
 =head1 AUTHOR
 
-Nobuo Danjou E<lt>danjou@soffritto.orgE<gt>
+Nobuo Danjou E<lt>nobuo.danjou@gmail.comE<gt>
 
 =head1 SEE ALSO
 
